Package {RcppFarmHash}


Type: Package
Title: Interface to the Google 'FarmHash' Family of Hash Functions
Version: 0.0.4
Date: 2026-09-06
Description: The Google 'FarmHash' family of hash functions is used by the Google 'BigQuery' data warehouse via the 'FARM_FINGERPRINT' function. This package permits to calculate these hash digest fingerprints directly from R, and uses the included 'FarmHash' files written by G. Pike and copyrighted by Google, Inc.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Imports: Rcpp (≥ 1.0.7)
LinkingTo: Rcpp, RcppInt64
Suggests: bit64
URL: https://github.com/eddelbuettel/rcppfarmhash/, https://dirk.eddelbuettel.com/code/rcpp.farmhash.html
BugReports: https://github.com/eddelbuettel/rcppfarmhash/issues
RoxygenNote: 6.0.1
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2026-09-06 12:07:15 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre], Geoff Pike [aut] (Author of FarmHash), Google, Inc. [cph] (Copyright for FarmHash)
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-09-06 12:20:02 UTC

Interface to the Google 'FarmHash' Family of Hash Functions

Description

The Google 'FarmHash' family of hash functions is used by the Google 'BigQuery' data warehouse via the 'FARM_FINGERPRINT' function. This package permits to calculate these hash digest fingerprints directly from R, and uses the included 'FarmHash' files written by G. Pike and copyrighted by Google, Inc.

Package Content

Index of help topics:

RcppFarmHash-package                                        Interface to the Google 'FarmHash' Family of Hash Functions
farmhash                                                    Compute a 'FarmHash' digest for a vector of strings

Maintainer

Dirk Eddelbuettel <edd@debian.org>

Author(s)

Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), Geoff Pike [aut] (Author of FarmHash), Google, Inc. [cph] (Copyright for FarmHash)


Compute a 'FarmHash' digest for a vector of strings

Description

Compute a 'FarmHash' digest for a vector of strings

Usage

farmhash(sv)

Arguments

sv

Vector of strings for which a hash digest is requested

Value

A vector of integer64 values (using the bit64 package to ‘decode’ the appropriate binary payload from a numeric vector).

Examples

if (requireNamespace("bit64", quietly=TRUE)) {
   suppressMessages(library(bit64))
}
farmhash(c("foo", "bar", "baz"))